@@ -1,13 +1,12 @@
 #!/usr/bin/env python
 
+import argparse
 import glob
 import logging
 import sys
 
-import argparse
-
 from pymchelper.estimator import ErrorEstimate
-from pymchelper.input_output import convertfrompattern, convertfromlist
+from pymchelper.input_output import convertfromlist, convertfrompattern
 from pymchelper.writers.common import Converters
 from pymchelper.writers.plots import ImageWriter, PlotAxis
 
@@ -18,7 +17,6 @@ def add_default_options(parser):
     import pymchelper
     parser.add_argument('input', help='input filename, file list or pattern', type=str)
     parser.add_argument('output', help='output filename or directory', nargs='?')
-    parser.add_argument('-j', '--jobs', help='number of parallel jobs to use (-1 means all CPUs)', default=-1, type=int)
     parser.add_argument('--many', help='automatically merge data from various sources', action="store_true")
     parser.add_argument('-a', '--nan', help='ignore NaN in averaging', action="store_true")
     parser.add_argument('-e', '--error',
@@ -39,12 +37,13 @@ def add_default_options(parser):
 def main(args=None):
     if args is None:
         args = sys.argv[1:]
-    import pymchelper
     import os
 
+    import pymchelper
+
     _progname = os.path.basename(sys.argv[0])
     _helptxt = 'Universal converter for FLUKA and SHIELD-HIT12A output files.'
-    _epitxt = '''Type '{:s} <converter> --help' for help on a specific converter.'''.format(_progname)
+    _epitxt = f"Type '{_progname} <converter> --help' for help on a specific converter."
 
     parser = argparse.ArgumentParser(description=_helptxt, epilog=_epitxt)
 
@@ -124,7 +123,7 @@ def main(args=None):
         # TODO add filename discovery
         files = sorted(glob.glob(parsed_args.input))
         if not files:
-            logger.error('File does not exist: ' + parsed_args.input)
+            logger.error(f'File {parsed_args.input} does not exist: ')
 
         # check if output should be interpreted as a filename
         if not parsed_args.many and len(files) == 1:
@@ -136,7 +135,7 @@ def main(args=None):
             output_dir = parsed_args.output
             # check if output directory exists
             if output_dir and not os.path.exists(output_dir):
-                logger.warning("Directory {:s} does not exist, creating.".format(output_dir))
+                logger.warning(f"Directory {output_dir} does not exist, creating.")
                 os.makedirs(output_dir)
         else:
             output_dir = '.'
@@ -146,8 +145,7 @@ def main(args=None):
         if parsed_args.many:
             status = convertfrompattern(parsed_args.input, output_dir,
                                         converter_name=parsed_args.command, options=parsed_args,
-                                        error=parsed_args.error, nan=parsed_args.nan,
-                                        jobs=parsed_args.jobs, verbose=parsed_args.verbose)
+                                        error=parsed_args.error, nan=parsed_args.nan)
         else:
             status = convertfromlist(parsed_args.input,
                                      error=parsed_args.error, nan=parsed_args.nan, outputdir=output_dir,
